#!/bin/sh -e


# Default settings
defcfg="config-s3c24xx"
curcfg=".config"
rebuild="n"
clean="n"
makecmd="nice make"
makeflags="-w"
makejobs="-j 4"

die() {
  echo "$0: ERROR: $1"
  exit 1
}

usage() {
  echo "Usage: $0 {rebuild|silent|verbose|single|config-*}"
  exit 1
}

make_clean() {
  echo "**** Cleaning...."
  ${makecmd} ${makeflags} distclean
}

make_config() {
  echo "**** Configuring with ${defcfg}..."
  cat "${defcfg}" > "${curcfg}"
  ${makecmd} ${makeflags} oldconfig
}

make_build() {
  echo "**** Building..."
  ${makecmd} ${makeflags} ${makejobs}
}

make_install() { 
  echo "**** Installing..."
  ${makecmd} ${makeflags} install
}

# Main starts here
while test -n "$1"; do
  case "$1" in
  rebuild)
    rebuild="y"
    ;;
  clean)
    clean="y"
    ;;
  silent)
    makeflags="-ws"
    ;;
  verbose)
    makeflags="-w"
    ;;
  single)
    makejobs=""
    ;;
  config-*)
    if test ! -f "$1"; then
      die "$1 does not exist!"
    fi
    if test -f "${curcfg}" && ! rm -f "${curcfg}"; then
      die "Unable to remove ${curcfg}!"
    fi
    defcfg="$1"
    ;;
  *)
    usage
    ;;
  esac
  shift
done

if test "${rebuild}" = "y"; then
  make_clean
  make_config
elif test "${clean}" = "y"; then
  make_clean
  echo "**** Successfully cleaned busybox."
  exit 0
elif test ! -f "${curcfg}" -o "${defcfg}" -nt "${curcfg}"; then
  make_config
fi

make_build
make_install "CONFIG_PREFIX=./_install"

echo "**** Successfully built busybox:"
ls -l _install/bin/busybox

# EOF
